==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Arcos y círculos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en los segmentos de línea (longitud fija)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en los segmentos de línea (ángulo fijo)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translation>Elipses</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en polilínea con segmentos de arco</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en polilínea con segmentos de línea</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translation>Splines</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>Dimensiones</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en las líneas, los sólidos y los textos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translatorcomment>--google--
Dibujar sombreados y rellenos
Dibuja texturas y rellenos sólidos
Sombreado/Relleno</translatorcomment>
        <translation>Escotillas</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en líneas</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>&amp;Bloques</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en entidades</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>&amp;Explotar</translation>
    </message>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>Modificar</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Expota</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+133"/>
        <source>Spline segments:</source>
        <translation>Segmentos de spline:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Segmentos de elipse:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Spline approximation tolerance:</source>
        <translation>Spline tolerancia:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Arcos y círculos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en los segmentos de línea (longitud fija)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en los segmentos de línea (ángulo fijo)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translation>Elipses</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en polilínea con segmentos de arco</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en polilínea con segmentos de línea</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translation>Splines</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>Dimensiones</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en las líneas, los sólidos y los textos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translatorcomment>--google--
Dibujar sombreados y rellenos
Dibuja texturas y rellenos sólidos
Sombreado/Relleno</translatorcomment>
        <translation>Escotillas</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en líneas</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>&amp;Bloques</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en entidades</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>&amp;Explotar</translation>
    </message>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>Modificar</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Expota</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+197"/>
        <source>Explode text glyphs to polylines</source>
        <translation>Explotar contornos de texto en polilíneas</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spline segments:</source>
        <translation>Segmentos de spline:</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Segmentos de elipse:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Explode splines to polylines with line segments</source>
        <translation>Explotar splines a polilíneas con segmentos de línea</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Explode multiline texts into multiple simple text blocks</source>
        <translation>Descomponer texto de varias líneas en varios bloques de texto simples</translation>
    </message>
    <message>
        <location line="-31"/>
        <source>Spline approximation tolerance:</source>
        <translation>Spline tolerancia:</translation>
    </message>
</context>
</TS>
